@@ -11,7 +11,7 @@ use POE::Component::IRC::Plugin qw(PCI_EAT_NONE PCI_EAT_PLUGIN);
 use POE::Component::IRC::Plugin::URI::Find;
 use POE::Wheel::Run;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 my $uri_title_code = <<'END';
 use strict;
@@ -208,6 +208,17 @@ sub _mirror_imgur {
         requests_redirectable => [qw(GET HEAD POST)],
     );
 
+    if (defined $self->{Imgur_user} && defined $self->{Imgur_pass}) {
+        $ua->post(
+            'http://imgur.com/signin',
+            {
+                username => $self->{Imgur_user},
+                password => $self->{Imgur_pass},
+                submit   => '',
+            },
+        );
+    }
+
     my $res = $ua->get("http://imgur.com/api/upload/?url=$uri");
 
     my $imgur;
@@ -343,6 +354,11 @@ Example:
 B<'URI_title'>, whether or not to include a title produced by
 L<URI::Title|URI::Title>. Defaults to true.
 
+B<'Imgur_user'>, an Imgur username. If provided, the images will uploaded to
+Imgur will be under this account rather than anonymously.
+
+B<'Imgur_pass'>, an Imgur account password to go with B<'ImgurUser'>.
+
 B<'Method'>, how you want messages to be delivered. Valid options are
 'notice' (the default) and 'privmsg'.
 
